/**
 * @fileOverview Генератор простых умных паролей
 * @author zm8
 * @link http://axisful.me
 * @license GNU GPLv3
 */
var oktoPassword = {
    
    /**
     * Массив с дозволенными симловами в пароле
     *
     * @type {Array}
     */
    symbols: [
        0, 1, 2, 3, 4, 5, 6, 7, 8, 9,
        'A', 'C', 'D', 'E', 'F', 'G', 'J', 'H', 'K', 'L', 'M', 'N', 'P', 'Q',
        'R', 'T', 'V', 'U', 'W', 'X', 'Y', 'Z'
    ],

    /**
     * Длина пароля
     *
     * @type {Number}
     */
    passLen: 8,

    /**
     * Генерировать из символов случайный пароль
     *
     * @param {HTMLElement} elem Поле, куда будет записан пароль
     */
    generate: function(elem){
        var pass = '',
            passLen = this.passLen;
    
        while (passLen--) {
            pass += this.getRandomSym();
        }

        elem.value = pass;
    },

    /**
     * Возвращает случайный символ из массива symbols
     *
     * @return {String|Number}
     */
    getRandomSym: function(){
        (!this._symLen) && (this._symLen = this.symbols.length);

        return this.symbols[Math.floor(Math.random() * this._symLen)];
    },

    /**
     * Возвратить список символов, которые используются для генерации
     *
     * @param {String} delimeter Разделитель [', ']
     * @return {String}
     */
    printAllowedSyms: function(delimeter){
        return this.symbols.join(delimeter || ', ');
    },

    /**
     * Получить количество вариантов для текущей конфигурации генератора
     *
     * @return {Number}
     */
    getVariantsAmount: function(){
        return Math.pow(this.symbols.length, this.passLen);
    }
}